@@ -1,8 +1,8 @@
 import struct
 import logging
-from date_time_utils import get_zone, FORMATS
+from e6xdb.date_time_utils import FORMATS
 from datetime import datetime, timedelta
-from pytz import timezone
+from e6xdb.constants import ZONE
 
 _logger = logging.getLogger(__name__)
 
@@ -77,6 +77,9 @@ class FieldInfo:
     def get_field_type(self):
         return self.field_type
 
+    def get_name(self):
+        return self.name
+
 
 def get_query_columns_info(buffer):
     result_meta_bytes = DataInputStream(buffer)
@@ -99,9 +102,6 @@ def read_values_from_array(query_columns_description: list, dis: DataInputStream
     for i in query_columns_description:
         dtype = i.get_field_type()
         isPresent = dis.read_byte()
-        zone = i.get_zone()
-        zone = get_zone(zone)
-        time_zone = timezone(zone)
         date_format = i.get_format()
         if date_format is None:
             date_format = "%Y-%m-%d %H:%M:%S"
@@ -122,8 +122,7 @@ def read_values_from_array(query_columns_description: list, dis: DataInputStream
                 value_array.append(date.strftime(date_format))
             elif dtype == "DATETIME":
                 epoch_days = dis.read_long()
-                date_time = datetime.fromtimestamp(epoch_days)
-                date_time.replace(tzinfo=time_zone)
+                date_time = datetime.fromtimestamp(epoch_days, ZONE)
                 value_array.append(date_time.strftime(date_format))
             elif dtype == "STRING" or dtype == "ARRAY" or dtype == "MAP" or dtype == "STRUCT":
                 value_array.append(dis.read_utf().decode())
